==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mk/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Средства задолжени на :name',
    'bulk_update_warn'	=> 'Ќе ажурирате :user_count корисници. Не можете да ги менувате вашите сопствени кориснички атрибути користејќи го овој формулар, и мора да правите измени на вашиот кориснички профил поединечно.',
    'bulk_update_help'	=> 'Оваа форма ви овозможува да ажурирате повеќе корисници одеднаш. Пополнете ги полињата што треба да ги промените. Сите полиња што остануваат празни ќе останат непроменети.',
    'current_assets'    => 'Средствата кои моментално се задолжени на овој корисник',
    'clone'             => 'Клонирај корисник',
    'contact_user'      => 'Контактирај го/ја :name',
    'edit'              => 'Ажурирај корисник',
    'filetype_info'     => 'Дозволени типови на датотеки се png, gif, jpg, jpeg, doc, docx, pdf, txt, zip и rar.',
    'history_user'      => 'Историја за :name',
	'info'				=> 'Информации',
    'restore_user'		=> 'Кликни тука за да ги вратите.',
    'last_login'        => 'Последна најава',
    'ldap_config_text'  => 'LDAP конфигурациските поставки може да се најдат во Admin > Settings. Избраната локација (опционално) ќе биде поставена за сите увезени корисници.',
    'print_assigned'    => 'Печати задолжение',
    'software_user'     => 'Софтвер задолжен на :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Погледнете го/ја :name',
    'usercsv'           => 'CSV датотека',
    'two_factor_admin_optin_help' => 'Вашите тековни администраторски поставки овозможуваат селективно спроведување на автентикација со два фактори. ',
    'two_factor_enrolled' => 'Поврзан уред за 2FA ',
    'two_factor_active'   => '2FA активна',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mk/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Средства задолжени на :name',
    'bulk_update_warn'	=> 'Ќе ажурирате :user_count корисници. Не можете да ги менувате вашите сопствени кориснички атрибути користејќи го овој формулар, и мора да правите измени на вашиот кориснички профил поединечно.',
    'bulk_update_help'	=> 'Оваа форма ви овозможува да ажурирате повеќе корисници одеднаш. Пополнете ги полињата што треба да ги промените. Сите полиња што остануваат празни ќе останат непроменети.',
    'current_assets'    => 'Средствата кои моментално се задолжени на овој корисник',
    'clone'             => 'Клонирај корисник',
    'contact_user'      => 'Контактирај го/ја :name',
    'edit'              => 'Ажурирај корисник',
    'filetype_info'     => 'Дозволени типови на датотеки се png, gif, jpg, jpeg, doc, docx, pdf, txt, zip и rar.',
    'history_user'      => 'Историја за :name',
    'info'				=> 'Информации',
    'restore_user'		=> 'Кликни тука за да ги вратите.',
    'last_login'        => 'Последна најава',
    'ldap_config_text'  => 'LDAP конфигурациските поставки може да се најдат во Admin > Settings. Избраната локација (опционално) ќе биде поставена за сите увезени корисници.',
    'print_assigned'    => 'Печати задолжение',
    'software_user'     => 'Софтвер задолжен на :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Погледнете го/ја :name',
    'usercsv'           => 'CSV датотека',
    'two_factor_admin_optin_help' => 'Вашите тековни администраторски поставки овозможуваат селективно спроведување на автентикација со два фактори. ',
    'two_factor_enrolled' => 'Поврзан уред за 2FA ',
    'two_factor_active'   => '2FA активна',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
